==> jc-1.4.0.tar.gz: java/rmi/dgc/Lease.h <==
// public final class java.rmi.dgc.Lease

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d000ed0debd501d0 java_rmi_dgc_Lease

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_dgc_Lease_H_
#define _JC_java_rmi_dgc_Lease_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_dgc_VMID$object;

// Typedefs
typedef struct _jc_java_rmi_dgc_Lease$sub_refs	_jc_java_rmi_dgc_Lease$sub_refs;
typedef struct _jc_java_rmi_dgc_Lease$sub_nonrefs	_jc_java_rmi_dgc_Lease$sub_nonrefs;
typedef struct _jc_java_rmi_dgc_Lease$refs	_jc_java_rmi_dgc_Lease$refs;
typedef struct _jc_java_rmi_dgc_Lease$nonrefs	_jc_java_rmi_dgc_Lease$nonrefs;
typedef struct _jc_java_rmi_dgc_Lease$object	_jc_java_rmi_dgc_Lease$object;

typedef struct _jc_java_rmi_dgc_Lease$fields_struct	_jc_java_rmi_dgc_Lease$fields_struct;
typedef const struct _jc_java_rmi_dgc_Lease$vmethods	_jc_java_rmi_dgc_Lease$vmethods;
typedef const struct _jc_java_rmi_dgc_Lease$vtable	_jc_java_rmi_dgc_Lease$vtable;
typedef const struct _jc_java_rmi_dgc_Lease$vtype	_jc_java_rmi_dgc_Lease$vtype;

// Class fields structure
struct _jc_java_rmi_dgc_Lease$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_dgc_Lease$fields_struct _jc_java_rmi_dgc_Lease$class_fields;

// Constructors
extern void _jc_java_rmi_dgc_Lease$method$_init$10b3f25b475f38f7(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *, struct _jc_java_rmi_dgc_VMID$object *, jlong);

// Virtual methods
extern struct _jc_java_rmi_dgc_VMID$object *_jc_java_rmi_dgc_Lease$method$getVMID$c0daf897f81bff2e(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *);
extern jlong _jc_java_rmi_dgc_Lease$method$getValue$738f22e2bb5f71e8(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_dgc_Lease$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_dgc_Lease$method_info$getVMID$c0daf897f81bff2e;
extern _jc_method _jc_java_rmi_dgc_Lease$method_info$getValue$738f22e2bb5f71e8;
extern _jc_method _jc_java_rmi_dgc_Lease$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_rmi_dgc_Lease$vmethods {
	struct _jc_java_rmi_dgc_VMID$object	*(*getVMID$c0daf897f81bff2e)(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *);
	jlong	(*getValue$738f22e2bb5f71e8)(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *);
};

// Vtable
struct _jc_java_rmi_dgc_Lease$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_dgc_Lease$vmethods	java_rmi_dgc_Lease;
};

// Vtype
struct _jc_java_rmi_dgc_Lease$vtype {
	_jc_type			type;
	_jc_java_rmi_dgc_Lease$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_dgc_Lease$sub_refs {
	struct _jc_java_rmi_dgc_VMID$object	*vmid;
};

// Reference instance fields (object)
struct _jc_java_rmi_dgc_Lease$refs {
    _jc_java_rmi_dgc_Lease$sub_refs	java_rmi_dgc_Lease;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_dgc_Lease$sub_nonrefs {
	jlong	value;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_dgc_Lease$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_dgc_Lease$sub_nonrefs	java_rmi_dgc_Lease;
};

// Object instance structure
struct _jc_java_rmi_dgc_Lease$object {
	_jc_java_rmi_dgc_Lease$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_dgc_Lease$vtype	*vtype;
	_jc_java_rmi_dgc_Lease$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_dgc_Lease$vtype _jc_java_rmi_dgc_Lease$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_dgc_Lease, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_dgc_Lease$class_object;

#endif	/* _JC_java_rmi_dgc_Lease_H_ */

==> jc-1.4.6.tar.gz: java/rmi/dgc/Lease.h <==
// public final class java.rmi.dgc.Lease

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d000ed0debd501d0 java_rmi_dgc_Lease

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_dgc_Lease_H_
#define _JC_java_rmi_dgc_Lease_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_dgc_VMID$object;

// Typedefs
typedef struct _jc_java_rmi_dgc_Lease$sub_refs	_jc_java_rmi_dgc_Lease$sub_refs;
typedef struct _jc_java_rmi_dgc_Lease$sub_nonrefs	_jc_java_rmi_dgc_Lease$sub_nonrefs;
typedef struct _jc_java_rmi_dgc_Lease$refs	_jc_java_rmi_dgc_Lease$refs;
typedef struct _jc_java_rmi_dgc_Lease$nonrefs	_jc_java_rmi_dgc_Lease$nonrefs;
typedef struct _jc_java_rmi_dgc_Lease$object	_jc_java_rmi_dgc_Lease$object;

typedef struct _jc_java_rmi_dgc_Lease$fields_struct	_jc_java_rmi_dgc_Lease$fields_struct;
typedef const struct _jc_java_rmi_dgc_Lease$vmethods	_jc_java_rmi_dgc_Lease$vmethods;
typedef const struct _jc_java_rmi_dgc_Lease$vtable	_jc_java_rmi_dgc_Lease$vtable;
typedef const struct _jc_java_rmi_dgc_Lease$vtype	_jc_java_rmi_dgc_Lease$vtype;

// Class fields structure
struct _jc_java_rmi_dgc_Lease$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_dgc_Lease$fields_struct _jc_java_rmi_dgc_Lease$class_fields;

// Constructors
extern void _jc_java_rmi_dgc_Lease$method$_init$10b3f25b475f38f7(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *, struct _jc_java_rmi_dgc_VMID$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_rmi_dgc_VMID$object *_jc_java_rmi_dgc_Lease$method$getVMID$c0daf897f81bff2e(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_rmi_dgc_Lease$method$getValue$738f22e2bb5f71e8(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_dgc_Lease$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_dgc_Lease$method_info$getVMID$c0daf897f81bff2e;
extern _jc_method _jc_java_rmi_dgc_Lease$method_info$getValue$738f22e2bb5f71e8;
extern _jc_method _jc_java_rmi_dgc_Lease$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_rmi_dgc_Lease$vmethods {
	struct _jc_java_rmi_dgc_VMID$object	*(*getVMID$c0daf897f81bff2e)(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *) _JC_JCNI_ATTR;
	jlong	(*getValue$738f22e2bb5f71e8)(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_dgc_Lease$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_dgc_Lease$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_dgc_Lease$vmethods	java_rmi_dgc_Lease;
};

// Vtype
struct _jc_java_rmi_dgc_Lease$vtype {
	_jc_type			type;
	_jc_java_rmi_dgc_Lease$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_dgc_Lease$sub_refs {
	struct _jc_java_rmi_dgc_VMID$object	*vmid;
};

// Reference instance fields (object)
struct _jc_java_rmi_dgc_Lease$refs {
    _jc_java_rmi_dgc_Lease$sub_refs	java_rmi_dgc_Lease;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_dgc_Lease$sub_nonrefs {
	jlong	value;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_dgc_Lease$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_dgc_Lease$sub_nonrefs	java_rmi_dgc_Lease;
};

// Object instance structure
struct _jc_java_rmi_dgc_Lease$object {
	_jc_java_rmi_dgc_Lease$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_dgc_Lease$vtype	*vtype;
	_jc_java_rmi_dgc_Lease$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_dgc_Lease$vtype _jc_java_rmi_dgc_Lease$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_dgc_Lease, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_dgc_Lease$class_object;

#endif	/* _JC_java_rmi_dgc_Lease_H_ */
